@@ -104,10 +104,6 @@ static PlayerContainer::Cap capFromName(const QString& capName)
         return PlayerContainer::CanGoNext;
     else if (capName == QLatin1String("CanGoPrevious"))
         return PlayerContainer::CanGoPrevious;
-    else if (capName == QLatin1String("CanPlay"))
-        return PlayerContainer::CanPlay;
-    else if (capName == QLatin1String("CanPause"))
-        return PlayerContainer::CanPause;
     return PlayerContainer::NoCaps;
 }
 
@@ -235,8 +231,8 @@ void PlayerContainer::copyProperty(const QString& propName, const QVariant& _val
         } else if (propName == QLatin1String("Metadata")) {
 
             if (updType == UpdatedSignal) {
-                QDBusObjectPath oldTrackId(data().value(QStringLiteral("Metadata")).toMap().value(QStringLiteral("mpris:trackid")).toString());
-                QDBusObjectPath newTrackId(value.toMap().value(QStringLiteral("mpris:trackid")).toString());
+                const QString oldTrackId = data().value(QStringLiteral("Metadata")).toMap().value(QStringLiteral("mpris:trackid")).toString();
+                const QString newTrackId = value.toMap().value(QStringLiteral("mpris:trackid")).toString();
                 if (oldTrackId != newTrackId) {
                     setData(QStringLiteral("Position"), static_cast<qlonglong>(0));
                     setData(POS_UPD_STRING, QDateTime::currentDateTimeUtc());
